@@ -155,6 +155,20 @@ def deploy_function(
             raise Exception(f"Function deployment error: {function.error=}")
 
 
+def get_function_metadata(client, function_call_info):
+   function_id=function_call_info["function_id"]
+   function = client.functions.retrieve(id=function_id)
+   metadata = dict(
+      external_id=function.external_id,
+      description=function.description,
+      owner=function.owner,
+      status=function.status,
+      file_id=function.file_id,
+      created_time=function.created_time
+   )
+   return metadata
+
+
 def call_function(function_name, data):
     """
     Call a function deployed in CDF
@@ -268,12 +282,12 @@ def upload_folder(
     
     Params:
         - external_id: external id (should be unique in the CDF project)
-        - path: path of local folder where content is stored
+        - path: (Path) path of local folder where content is stored
         - metadata: dictionary with file metadata
         - target_folder: path where compressed file should be stored
         - overwrite: if overwrite==False and `external_id` exists => exception
     """
-    base_name = os.path.join(path, 'archive')
+    base_name = path / 'archive'
     archive_name = make_archive(base_name, 'gztar', path)
     file_info = upload_file(
         external_id, 
@@ -295,11 +309,11 @@ def download_folder(external_id, path):
 
     Params:
     - external_id: external id
-    - path: path of local folder where content will be stored
+    - path: (Path) path of local folder where content will be stored
     """
-    base_name = os.path.join(path, 'archive.tar.gz')
+    base_name = path / 'archive.tar.gz'
     download_file(dict(external_id=external_id), base_name)
-    unpack_archive(base_name, os.path.dirname(base_name))
+    unpack_archive(base_name, base_name.parent)
     os.remove(base_name)
     logging.info(f"Model file/s downloaded to {path}")
 
