@@ -23,21 +23,23 @@ def validate_categorical(setting, name, allowed):
 
 @dataclass
 class EnvVar():
-    env: str
+    env: Optional[str] = None
     service_name: Optional[str] = None
     google_project_id: Optional[str] = None
     platform: Optional[str] = None
     local_deployment: bool = False
 
     def __post_init__(self):        
-        validate_categorical(self.env, "Environment", ["dev", "test", "prod"])
+        if self.env:
+            validate_categorical(self.env, "Environment", ["dev", "test", "prod"])
+        else:
+            logging.warning("ENV environmental variable is not set")
         validate_categorical(self.platform, "Platform", ["cdf", "gc", None])
-        if self.env != 'dev':
+        if (self.env and self.env != 'dev'):
             validate_categorical(self.service_name, "Service  name", 
                 ["training", "prediction"])
 
 
-# Read environmental variables
 def _read_env_vars():
     """
     Read environmental variables and initialize EnvVar object with those that
